<?php

/**
 * Created by PhpStorm.
 * User: sebastien
 * Date: 2018-12-13
 * Time: 21:50
 */

namespace WeLoveCustomers\Connector\Block;

use WeLoveCustomers\Connector\Block\Adminhtml\System\Config\Url;
use WeLoveCustomers\Connector\Endpoint\ReferralInfosEndpoint;
use WeLoveCustomers\Connector\Endpoint\StatsEndpoint;
use WeLoveCustomers\Connector\Model\Offer;
use WeLoveCustomers\Connector\Model\Stats;

class Reports extends \Magento\Framework\View\Element\Template
{

    /**
     * @var ReferralInfosEndpoint
     */
    private $endpoint;

    /**
     * @var \WeLoveCustomers\Connector\DTO\ReferralInfosApiResponse
     */
    private $referral;

    /**
     * @var Url
     */
    private $url;

    /**
     * @var Stats
     */
    private $stats;

    /**
     * Reports constructor.
     * @param \Magento\Framework\View\Element\Template\Context $context
     * @param ReferralInfosEndpoint $endpoint
     * @param Url $url
     */
    public function __construct(
        \Magento\Framework\View\Element\Template\Context $context,
        ReferralInfosEndpoint $endpoint,
        StatsEndpoint $statsEndpoint,
        Url $url
    ) {
        parent::__construct($context);
        $this->endpoint = $endpoint;
        $this->referral = $this->endpoint->findReferralInfos();
        $this->url = $url;
        $this->stats = $statsEndpoint->findStats();
    }

    /**
     * @return bool
     */
    public function isConfigValid()
    {
        return (bool)$this->referral;
    }

    /**
     * @return string
     */
    public function getMasterInfo()
    {
        $offer = $this->referral->masterOffer;
        return $this->getOfferInfo($offer);
    }

    /**
     * @return string
     */
    public function getSlaveInfo()
    {
        $offer = $this->referral->slaveOffer;
        return $this->getOfferInfo($offer);
    }

    /**
     * @param $offer
     * @return string
     */
    private function getOfferInfo($offer)
    {
        if ($offer) {
            switch ($offer->offerValueType) {
                case Offer::TYPE_AMOUNT:
                    return $offer->offerValue . "€";
                case Offer::TYPE_PERCENT:
                    return $offer->offerValue . "%";
                case Offer::TYPE_FREE_SHIPPING:
                    return "Free shipping";
            }
        }
        return "<p></p>";
    }

    /**
     * @return string
     */
    public function getNPSScore()
    {
        $score = $this->stats->npsScore;
        return $score ? $score : "-";
    }


    /**
     * @return string
     */
    public function getInvitationNumber()
    {
        return $this->stats->contact;
    }

    /**
     * @return mixed
     */
    public function getFatherNumber()
    {
        return $this->stats->father;
    }

    public function getSonNumber()
    {
        return $this->stats->slave;
    }

    /**
     * @return float|null
     */
    private function getSponringPercent()
    {
        $nbSlave = $this->referral->availableCodeSlave;
        $nbMaster = $this->referral->availableCodesMaster;

        if ($nbSlave) {
            return ($nbMaster / $nbSlave) * 100;
        }

        return null;
    }

    /**
     * @return string
     */
    public function getSponsoringClass($value)
    {
        return $value ? "info" : "warning";
        /*
         * $percent = $this->getSponringPercent();

        if($percent) {
            if($percent > 30) {
                return "success";
            }

            if($percent > 10) {
                return "warning";
            }

            return "danger";
        }*/

        return "info";
    }

    /**
     * @return string
     */
    public function getNPSClass()
    {
        $score = $this->stats->npsScore;

        if ($score) {
            if ($score > 20) {
                return "success";
            }

            if ($score > -20) {
                return "warning";
            }

            return "danger";
        }

        return "info";
    }

    /**
     * @return string
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getDashboardUrl()
    {
        return $this->url->getLink();
    }
}
