<?php

/**
 * Created by PhpStorm.
 * User: thibault
 * Date: 2023-04-07
 * Time: 09:52
 */

namespace WeLoveCustomers\Connector\Controller\Purchase;

use Magento\Framework\App\Action\Context;
use WeLoveCustomers\Connector\Endpoint\CheckConfigEndpoint;

class Details extends \Magento\Framework\App\Action\Action
{

    /**
     * @var CheckConfigEndpoint
     */
    private $endpoint;

    /**
     * @var request
     */
    protected $request;
    /**
     * @var scopeconfig
     */
    protected $scopeconfig;
    /**
     * @var orderinterface
     */
    protected $orderinterface;
    /**
     * @var order
     */
    protected $order;


    public function __construct(
        Context $context,
        \Magento\Sales\Model\OrderRepository $order,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeconfig,
        \Magento\Framework\App\Request\Http $request,
        \Magento\Sales\Api\Data\OrderInterface $orderinterface
    ) {
        parent::__construct($context);
        $this->order = $order;
        $this->scopeconfig = $scopeconfig;
        $this->request = $request;
        $this->orderinterface = $orderinterface;
        $this->endpoint = new CheckConfigEndpoint();
    }


    public function execute()
    {
        $params = $this->request->getParams();

        if (!$params) {
            echo "no params";
            return false;
        }
        $apikeyparam = $this->request->getParam('apikey');
        $apiglueparam = $this->request->getParam('apiglue');
        $orderidparam = $this->request->getParam('orderid');

        if (!$apikeyparam || !$apiglueparam || !$orderidparam) {
            echo "paramètre manquant";
            return false;
        }

        $apikey = $this->scopeconfig->getValue('welovecustomersconnector/general/api_key');
        $apiglue = $this->scopeconfig->getValue('welovecustomersconnector/general/api_glue');

        if ($apikey != $apikeyparam || $apiglue != $apiglueparam) {
            echo "paramètre incorrecte";
            return false;
        }

        $orderIdType      = $this->scopeconfig->getValue('welovecustomersconnector/general/order_id_type');
        if ($orderIdType == "incrementId") {
            $order = $this->orderinterface->loadByIncrementId($orderidparam);
            if (!$order->getEntityId()) {
                $order = $this->order->get($orderidparam);
                if (!$order->getEntityId()) {
                    echo "commande introuvable";
                    return false;
                }
            }
        } else {
            $order = $this->order->get($orderidparam);
            if (!$order->getEntityId()) {
                echo "commande introuvable";
                return false;
            }
        }

        $data = array();

        if ($orderIdType == "incrementId") {
            $data["order"] = $order->getIncrementId();
        } else {
            $data["order"] = $order->getEntityId();
        }

        $data["status"] = $order->getStatus();

        $items = $order->getAllVisibleItems();
        $i = 0;
        foreach ($items as $item) {
            $data["products"][$i]['name'] = $item->getData('name');
            $data["products"][$i]['sku'] = $item->getData('sku');
            $data["products"][$i]['qty'] = $item->getData('qty_ordered');
            $data["products"][$i]['pricePerUnit'] = $item->getData('base_price');
            $data["products"][$i]['pricePerUnitWithTax'] = $item->getData('base_price_incl_tax') - $item->getData('base_discount_amount');

            $i++;
        }

        header('Content-Type: application/json');

        echo json_encode($data);

        die;
    }
}
